ConstantVolume

Struct ConstantVolume 

pub struct ConstantVolume<TT, TR = TT> {
    pub delta_t: f64,
    pub translational_thermostat: TT,
    pub rotational_thermostat: TR,
}
Integrate bodies’ translational and rotational degrees of freedom in the microstate.

The ConstantVolume implementation follows the symplectic integration scheme by Tuckerman et al. 2006 for translational motion and Miller et al. 2002 for rotational motion.

Use NoThermostat to integrate trajectories that sample the microcanonical ensemble:

use hoomd_md::method::ConstantVolume;

let delta_t = 0.001;
let constant_volume = ConstantVolume::builder(delta_t).build();

Use Bussi (or one of the other thermostats) to integrate trajectories that sample the canonical ensemble:

use hoomd_md::{method::ConstantVolume, thermostat::Bussi};

let delta_t = 0.001;
let constant_volume = ConstantVolume::builder(delta_t)
    .thermostat(Bussi::default())
    .build();

Reference

Fields

delta_t: f64

The time step size.

translational_thermostat: TT

Translational thermostat.

rotational_thermostat: TR

Rotational thermostat.

Implementations

Source

impl ConstantVolume<NoThermostat, NoThermostat>

pub fn builder( delta_t: f64, ) -> ConstantVolumeBuilder<NoThermostat, NoThermostat>

Start building a new ConstantVolume.

The default builder uses the given value for delta_t and NoThermostat for both the translational and rotational thermostats. Call zero or more of the ConstantVolumeBuilder methods to set the thermostats.

Example
use hoomd_md::method::ConstantVolume;

let delta_t = 0.001;
let constant_volume = ConstantVolume::builder(delta_t).build();
Source

impl<TT, TR> ConstantVolume<TT, TR>

pub fn translational_thermostat(&self) -> &TT

Access the translational thermostat.

pub fn translational_thermostat_mut(&mut self) -> &mut TT

Access the translational thermostat (mutable).

pub fn rotational_thermostat(&self) -> &TR

Access the rotational thermostat.

pub fn rotational_thermostat_mut(&mut self) -> &mut TR

Access the rotational thermostat (mutable).