pub struct ConstantVolumeBuilder<TT, TR> { /* private fields */ }Expand description
Builder that constructs ConstantVolume.
Call ConstantVolume::builder to start building a new ConstantVolume.
Implementations
Sourceimpl<TT, TR> ConstantVolumeBuilder<TT, TR>
impl<TT, TR> ConstantVolumeBuilder<TT, TR>
Sourcepub fn translational_thermostat<T>(
self,
translational_thermostat: T,
) -> ConstantVolumeBuilder<T, TR>
pub fn translational_thermostat<T>( self, translational_thermostat: T, ) -> ConstantVolumeBuilder<T, TR>
Set the thermostat that applies to the translational degrees of freedom.
Example
use hoomd_md::{method::ConstantVolume, thermostat::Bussi};
let delta_t = 0.001;
let constant_volume = ConstantVolume::builder(delta_t)
.translational_thermostat(Bussi::default())
.build();Sourcepub fn rotational_thermostat<T>(
self,
rotational_thermostat: T,
) -> ConstantVolumeBuilder<TT, T>
pub fn rotational_thermostat<T>( self, rotational_thermostat: T, ) -> ConstantVolumeBuilder<TT, T>
Set the thermostat that applies to the rotational degrees of freedom.
Example
use hoomd_md::{method::ConstantVolume, thermostat::Bussi};
let delta_t = 0.001;
let constant_volume = ConstantVolume::builder(delta_t)
.rotational_thermostat(Bussi::default())
.build();Sourcepub fn thermostat<T: Clone>(self, thermostat: T) -> ConstantVolumeBuilder<T, T>
pub fn thermostat<T: Clone>(self, thermostat: T) -> ConstantVolumeBuilder<T, T>
Set the thermostat that applies to both translational and rotational degrees of freedom.
The given thermostat is cloned. The translational and rotational thermostats evolve independently.
Example
use hoomd_md::{method::ConstantVolume, thermostat::Bussi};
let delta_t = 0.001;
let constant_volume = ConstantVolume::builder(delta_t)
.thermostat(Bussi::default())
.build();Sourcepub fn build(self) -> ConstantVolume<TT, TR>
pub fn build(self) -> ConstantVolume<TT, TR>
Complete building a new ConstantVolume.
Example
use hoomd_md::method::ConstantVolume;
let delta_t = 0.001;
let constant_volume = ConstantVolume::builder(delta_t).build();Auto Trait Implementations
impl<TT, TR> Freeze for ConstantVolumeBuilder<TT, TR>
impl<TT, TR> RefUnwindSafe for ConstantVolumeBuilder<TT, TR>where
TT: RefUnwindSafe,
TR: RefUnwindSafe,
impl<TT, TR> Send for ConstantVolumeBuilder<TT, TR>
impl<TT, TR> Sync for ConstantVolumeBuilder<TT, TR>
impl<TT, TR> Unpin for ConstantVolumeBuilder<TT, TR>
impl<TT, TR> UnsafeUnpin for ConstantVolumeBuilder<TT, TR>where
TT: UnsafeUnpin,
TR: UnsafeUnpin,
impl<TT, TR> UnwindSafe for ConstantVolumeBuilder<TT, TR>where
TT: UnwindSafe,
TR: UnwindSafe,