Bussi

Struct Bussi 

pub struct Bussi { /* private fields */ }
Stochastic momentum rescaling.

The time constant $\tau$ sets how long the kinetic energy of the system takes to decay to equilibrium.

When $\tau$ is 0, the rescaling factor $\alpha$ is:

 \alpha = \sqrt{\frac{g kT}{K}}

where $K$ is the instantaneous kinetic energy of the corresponding translational or rotational degrees of freedom, $N$ is the number of degrees of freedom, and $g$ is a random value sampled from the gamma distribution $\Gamma(N, 1)$ with the probability density function:

   f_N(g) = \frac{1}{\Gamma{(N)}} g^{N-1} e^{-g}

When $\tau$ is non-zero, $\alpha$ is given by:

\alpha = \sqrt{e^{-\delta t / \tau}
     + (1 - e^{-\delta t / \tau}) \frac{(2 g + n^2) kT}{2 K}
     + 2 n \sqrt{e^{-\delta t / \tau} (1-e^{-\delta t / \tau})
        \frac{kT}{2 K}}}

where $\delta t$ is the integration time step size and $n$ is a random value sampled from the standard normal distribution $\mathcal{N}(0, 1)$.

Reference

Example

use hoomd_md::thermostat::Bussi;

let bussi = Bussi::new(0.5);

Implementations

Source

impl Bussi

pub fn new(tau: f64) -> Self

Construct a new Bussi thermostat with the given time constant.

Example
use hoomd_md::thermostat::Bussi;

let bussi = Bussi::new(0.5);
pub fn energy(&self) -> f64

The total energy of the thermostat.

Example
use hoomd_md::thermostat::Bussi;

let bussi = Bussi::new(0.1);
let energy = bussi.energy();