MartynaTuckermanTobiasKlein

Struct MartynaTuckermanTobiasKlein 

pub struct MartynaTuckermanTobiasKlein { /* private fields */ }
Nosé-Hoover thermostat.

MartynaTuckermanTobiasKlein adds a new degree of freedom ($\eta$) to a molecular dynamics simulation in such a way that the existing degrees of freedom sample a constant temperature ensemble. Each MartynaTuckermanTobiasKlein instance stores $\eta$ and its momentum, $\xi$, internally.

The extended Hamiltonian $H$ is:

   H = K + U
        + N kT \eta
        +  \frac{1}{2} N kT \tau^2\xi^2

Where $K$ is the kinetic energy of the system, $U$ is the potential energy of the system, $N$ is the number of degrees of freedom, and $kT$ is the temperature.

Following the Trotter decomposition of Liouvillian, MartynaTuckermanTobiasKlein integrates $\eta$ and $\xi$ forward by half time step $\frac{\delta t}{2}$ via the following procedure:

\begin{align*}

G_\mathrm{old} &= \frac{1}{\tau^2} \left( \frac{2 K}{N kT} - 1 \right) \\

\xi \left\{ t+\frac{\delta t} {4} \right\} &= \xi \{ t \} + G_\mathrm{old}\frac{\delta t}{4} \\

\alpha &= \exp\left[ -\xi \left\{ t+\frac{\delta t} {4} \right\} \frac{dt}{2} \right]  \\

K_{new} &= K \alpha^2 \\

\eta \left\{ t+\frac{\delta t} {2} \right\} &= \eta \{ t \} + \xi \left\{ t+\frac{\delta t} {4} \right\} \frac{\delta t}{2} \\

G_\mathrm{new} &= \frac{1}{\tau^2} \left( \frac{2 K_\mathrm{new} }{kT} - 1 \right) \\

\xi \left\{ t+\frac{\delta t} {2} \right\} &= \xi \left\{ t+\frac{\delta t} {4} \right\} + G_\mathrm{new} \frac{\delta t}{4}

\end{align*}

Warning

MartynaTuckermanTobiasKlein fails to sample the correct distribution when there are strong harmonic interactions in the system. In such situations, use Bussi or NoséHooverChain instead.

References

Example

use hoomd_md::thermostat::MartynaTuckermanTobiasKlein;

let thermostat = MartynaTuckermanTobiasKlein::zero(0.5.try_into()?);

Implementations

Source

impl MartynaTuckermanTobiasKlein

pub fn zero(tau: PositiveReal) -> Self

Construct a new MartynaTuckermanTobiasKlein thermostat with the given time constant, $\xi = 0$, and $\eta = 0$ .

This initial condition is likely to be very far from equilibrium which will result in wild kinetic energy oscillations for the first hundred to thousand time steps. Use thermalized to choose the initial position and momentum from a thermal distribution.

Example
use hoomd_md::thermostat::MartynaTuckermanTobiasKlein;

let thermostat = MartynaTuckermanTobiasKlein::zero(0.5.try_into()?);
pub fn thermalized<M, R: Rng + ?Sized>( rng: &mut R, tau: PositiveReal, macrostate: &M, degrees_of_freedom: usize, ) -> Self
where M: Temperature,

Construct a new MartynaTuckermanTobiasKlein thermostat with a random $\xi$ drawn from a thermal distribution.

Panics

This method will panic when degrees_of_freedom is 0.

Example
use hoomd_md::{
    TranslationalKineticEnergy, thermostat::MartynaTuckermanTobiasKlein,
};
use hoomd_microstate::{
    Body, Microstate,
    property::{DynamicPoint, Point},
};
use hoomd_simulation::macrostate::Isothermal;
use hoomd_vector::Cartesian;

let mut microstate = Microstate::builder()
    .bodies([
        Body::single_site(
            DynamicPoint {
                position: Cartesian::from([1.0, 2.0]),
                ..Default::default()
            },
            Point::default(),
        ),
        Body::single_site(
            DynamicPoint {
                position: Cartesian::from([-2.0, 3.0]),
                ..Default::default()
            },
            Point::default(),
        ),
    ])
    .try_build()?;

let macrostate = Isothermal { temperature: 1.5 };
let mut rng = microstate.counter().make_rng();
let translational_thermostat = MartynaTuckermanTobiasKlein::thermalized(
    &mut rng,
    0.5.try_into()?,
    &macrostate,
    microstate.translational_kinetic_energy().1,
);
microstate.increment_substep();
pub fn energy(&self) -> f64

The total energy of the thermostat.

Example
use hoomd_md::thermostat::MartynaTuckermanTobiasKlein;

let thermostat = MartynaTuckermanTobiasKlein::zero(0.5.try_into()?);

let energy = thermostat.energy();
pub fn eta(&self) -> f64

The thermostat’s position.

Example
use hoomd_md::thermostat::MartynaTuckermanTobiasKlein;

let thermostat = MartynaTuckermanTobiasKlein::zero(0.5.try_into()?);

let eta = thermostat.eta();
pub fn xi(&self) -> f64

The thermostat’s momentum.

Example
use hoomd_md::thermostat::MartynaTuckermanTobiasKlein;

let thermostat = MartynaTuckermanTobiasKlein::zero(0.5.try_into()?);

let xi = thermostat.xi();